﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;

namespace ForGet
{
   public class PackageRepository
   {
      static readonly string[] _supportedPackageExtenstions = new[] { "forpkg", "nupkg" };

      IEnumerable<string> _repos;

      public PackageRepository(IEnumerable<string> repos)
      {
         _repos = repos;
      }

      public IEnumerable<string> GetPackagesById(string id)
      {
         return
            from repo in _repos
            let repoPathforDependency = Path.Combine(repo, id)
            where Directory.Exists(repoPathforDependency)
               from extenstion in _supportedPackageExtenstions
                  from filePath in Directory.GetFiles(repoPathforDependency, string.Format("*.{0}", extenstion), SearchOption.AllDirectories)
                  select filePath;
      }

      public string GetPackage(string id, string version)
      {
         var expectedPackageNameWithoutExtension = string.Join(".", id, version);

         var matches =
            from package in GetPackagesById(id)
            let packageNameWithoutExtension = Path.GetFileNameWithoutExtension(package)
            where packageNameWithoutExtension.Equals(expectedPackageNameWithoutExtension, StringComparison.CurrentCultureIgnoreCase)
            select package;

         return matches.FirstOrDefault();
      }
   }
}
